@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <tagger name="catalan">
 <tagset>
- <!-- <def-label name="QUECNJ" closed="true">únic
+ <!-- <def-label name="QUECNJ" closed="true">Ãºnic
     <tags-item lemma="que" tags="cnjsub"/>
   </def-label> -->
   <def-label name="QUEREL" closed="true">
@@ -95,8 +95,12 @@
   <def-label name="NOMM">
     <tags-item tags="n.m.*"/>
   </def-label>
+  <def-label name="NOMMF">
+    <tags-item tags="n.mf.*"/>
+  </def-label>
   <def-label name="ANTROPONIM">
     <tags-item tags="np.ant.*"/>
+    <tags-item tags="np.cog.*"/>
   </def-label>
   <def-label name="TOPONIM">
     <tags-item tags="np.loc.*"/>
@@ -273,7 +277,7 @@
       <tags-item tags="det.def.m.*"/>
     </sequence>
   </def-mult>
- <def-mult name="PREPPOS" closed="true">
+<!-- <def-mult name="PREPPOS" closed="true">
     <sequence>
       <label-item label="PREP"/>
       <tags-item tags="det.pos.*"/>
@@ -284,7 +288,7 @@
       <label-item label="PREP"/>
       <tags-item tags="prn.pos.*"/> 
     </sequence>
-  </def-mult> <!--Per ara no funciona (no serveix), potser amb un nou corpus etiquetat desambiguaria correctament -->
+  </def-mult> --><!--Per ara no funciona (no serveix), potser amb un nou corpus etiquetat desambiguaria correctament -->
  
   <def-mult name="INFLEXPRNENC">
     <sequence>
@@ -418,6 +422,10 @@
       <label-item label="NOMM"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="NOMM"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     
     <label-sequence>
       <label-item label="NOMF"/>
@@ -427,6 +435,10 @@
       <label-item label="NOMF"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="NOMF"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="NOMM"/>
       <label-item label="ACRONIMOM"/>
@@ -451,6 +463,18 @@
       <label-item label="NOMF"/>
       <label-item label="ACRONIMOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="NOMMF"/>
+      <label-item label="ACRONIMOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOMMF"/>
+      <label-item label="ACRONIMOF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOMMF"/>
+      <label-item label="ACRONIMOMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="ACRONIMOM"/>
       <label-item label="NOMM"/>
@@ -459,6 +483,10 @@
       <label-item label="ACRONIMOM"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="ACRONIMOM"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="ACRONIMOF"/>
       <label-item label="NOMM"/>
@@ -467,6 +495,10 @@
       <label-item label="ACRONIMOF"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="ACRONIMOF"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="ACRONIMOMF"/>
       <label-item label="NOMM"/>
@@ -475,6 +507,10 @@
       <label-item label="ACRONIMOMF"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="ACRONIMOMF"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="ACRONIMOM"/>
       <label-item label="ACRONIMOM"/>
@@ -514,6 +550,18 @@
     <label-sequence>
       <label-item label="ANTROPONIM"/>
       <label-item label="VLEXIMP"/>
+    </label-sequence> 
+    <label-sequence>
+      <label-item label="PRNPOS"/>
+      <label-item label="NOMM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNPOS"/>
+      <label-item label="NOMF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNPOS"/>
+      <label-item label="NOMMF"/>
     </label-sequence>
     <label-sequence>
       <label-item label="TOPONIM"/>
@@ -631,6 +679,18 @@
       <label-item label="NPALTRES"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="ANTROPONIM"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="TOPONIM"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NPALTRES"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="ANTROPONIM"/>
       <label-item label="ACRONIMOM"/>
@@ -1015,6 +1075,10 @@
       <label-item label="CNJSUBS"/>
       <label-item label="VLEXIMP"/>
     </label-sequence>
+ <label-sequence><!-- 'si guanya' -->
+      <label-item label="CNJADV"/>
+      <label-item label="VLEXIMP"/>
+    </label-sequence>
 
     <label-sequence>
       <label-item label="QUEREL"/>
@@ -1032,6 +1096,10 @@
       <label-item label="CNJSUBS"/>
       <label-item label="VSERIMP"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="CNJADV"/>
+      <label-item label="VSERIMP"/>
+    </label-sequence>
    <label-sequence>
       <label-item label="QUEREL"/>
       <label-item label="VSERIMP"/>
@@ -1047,6 +1115,10 @@
      <label-sequence>
       <label-item label="CNJSUBS"/>
       <label-item label="VMODALIMP"/>
+    </label-sequence>
+     <label-sequence>
+      <label-item label="CNJADV"/>
+      <label-item label="VMODALIMP"/>
     </label-sequence>
     <label-sequence>
       <label-item label="QUEREL"/>
@@ -1156,6 +1228,10 @@
       <label-item label="DETNT"/>
       <label-item label="NOMF"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="DETNT"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="DETNT"/>
       <label-item label="ACRONIMOM"/>
@@ -1528,7 +1604,7 @@
       <label-item label="MOLTPREADV"/>
       <label-item label="SENT"/>
     </label-sequence>
-    <label-sequence><!--Afegides les 3 següents 30/11/05 MG -->
+    <label-sequence><!--Afegides les 3 segÃŒents 30/11/05 MG -->
       <label-item label="INTNOM"/>
       <label-item label="NOMF"/>
     </label-sequence>
@@ -1536,6 +1612,10 @@
       <label-item label="INTNOM"/>
       <label-item label="NOMM"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="INTNOM"/>
+      <label-item label="NOMMF"/>
+    </label-sequence>
     <label-sequence><!--13/01/06 -->
       <label-item label="MOLTADV"/>
       <label-item label="INTERJ"/>
